# FoundationKit - Core

A set of framework independent functions to interact with Foundation's NFT Market Protocol

Using React? You're probably best using the hooks package. [`@f8n/foundationkit-hooks`](/packages/hooks/README.md)

## Installation

```shell
yarn add @foundationkit/core
```

## Getting Started

You can import the library into your script and setup a Ethereum provider.

```html
<script type="module">
  import { getMarketInfo } from '@foundationkit/core';
  import { ethers } from 'ethers';
  const provider = new ethers.providers.JsonRpcProvider(
    'https://ethereum-node.com',
    'mainnet'
  );

  getMarketInfo({
    provider,
    contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
    tokenId: 8,
  }).then((data) => {
    console.log(data);
  });
</script>
```

## Setting the network

Foundations Market contracts are currently deployed to Mainnet and Göerli on Ethereum. To set the network being used you need to configure the provider being passed into the hooks.

### With Ethers.js

```html
<script type="module">
  import { getMarketInfo } from '@foundationkit/core';
  import { ethers } from 'ethers';
  const provider = new ethers.providers.JsonRpcProvider(
    'https://ethereum-node.com',
    'mainnet'
  );

  getMarketInfo({
    provider,
    contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
    tokenId: 8,
  }).then((data) => {
    console.log(data);
  });
</script>
```

## API

- [`getMarketInfo`](#getmarketinfo)
- [`sendBid`](#sendbid)
- [`sendBuyNow`](#sendbuynow)
- [`sendOffer`](#sendoffer)
- [`getLastSoldPrice`](#getlastsoldprice)
- [`getApproval`](#getapproval)
- [`setApproval`](#setapproval)
- [`setReserveAuction`](#setreserveauction)
- [`setBuyNow`](#setbuynow)
- [`cancelBuyNow`](#cancelbuynow)
- [`cancelReserveAuction`](#cancelreserveauction)
- [`acceptOffer`](#acceptoffer)
- [`finalizeReserveAuction`](#finalizereserveauction)
- [`getBalances`](#getbalances)

### `getMarketInfo`

Function for accessing a NFT's market information.

```js
import { getMarketInfo } from '@foundationkit/core';
```

#### Usage

An Provider must be passed in from either a library like wagmi or ethers.js.

```js
import { getMarketInfo } from '@foundationkit/core';

getMarketInfo({
  provider,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
{
  ownerAddress: string;
  isInEscrow: boolean;
  auction?: {
    isAuctionLive: boolean;
    highestBidderAddress: string;
    endsAt: number;
    currentBidAmount: {
      value: BigNumber;
      formatted: string;
    }
    id: number;
    link: string;
  }
  buyNow?: {
    amount: {
      value: BigNumber;
      formatted: string;
    }
    link: string;
  }
  offer?: {
    amount: {
      value: BigNumber;
      formatted: string;
    }
    offererAddress: string;
    offerExpiresAt: number;
    link: string;
  }
}
```

#### Configuration

##### provider (required)

An Ethereum Provider must be provided from a library like ethers.js.

```js
const provider = new ethers.providers.JsonRpcProvider(
  'https://ethereum-node.com',
  'mainnet'
);

getMarketInfo({
  provider,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are querying

```js
getMarketInfo({
  // provider,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are querying.

```js
getMarketInfo({
  // provider,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

---

### `sendBid`

Hook for placing a bid for a NFT that is currently in escrow of the Foundation Market contract.

```js
import { sendBid } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
sendBid({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like ethers.js.

```js
import { sendBid } from '@foundationkit/core';

sendBid({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are placing a bid on.

```js
import { sendBid } from '@foundationkit/core';

sendBid({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are placing a bid on.

```js
import { sendBid } from '@foundationkit/core';

sendBid({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### amount (required)

A string value representing the bid amount you are placing, it is read as eth.

```js
import { useSendBid } from '@foundationkit/core';

sendBid({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### referrer

A valid Ethereum address that will receive a referral fee of 1% of the sale price, if this NFT is bought via this hook. [Learn more about referrals](https://help.foundation.app/hc/en-us/articles/6155086291739)

```js
import { sendBid } from '@foundationkit/core';

sendBid({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
  referrer: '0x165CD37b4C644C2921454429E7F9358d18A45e14',
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { sendBid } from '@foundationkit/core';

function App() {
  const sendBid = useSendBid({
    // Will send 15% more gas, based on the estimate gas calculation
    gasMargin: 15,
  });
}
sendBid({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `sendBuyNow`

Function for buying at a Buy Now price for a NFT that is currently in escrow of the Foundation Market contract.

```js
import { sendBuyNow } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
import { sendBuyNow } from '@foundationkit/core';

sendBuyNow({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like ethers.js.

```js
import { sendBuyNow } from '@foundationkit/core';

sendBuyNow({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are buying.

```js
import { sendBuyNow } from '@foundationkit/core';

sendBuyNow({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are buying.

```js
import { sendBuyNow } from '@foundationkit/core';

sendBuyNow({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### referrer

A valid Ethereum address that will receive a referral fee of 1% of the sale price, if this NFT is bought via this hook. [Learn more about referrals](https://help.foundation.app/hc/en-us/articles/6155086291739)

```js
import { sendBuyNow } from '@foundationkit/core';

sendBuyNow({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  referrer: '0x165CD37b4C644C2921454429E7F9358d18A45e14',
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { sendBuyNow } from '@foundationkit/core';

sendBuyNow({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `sendOffer`

Function for placing an offer on an NFT.

```js
import { sendOffer } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
import { sendOffer } from '@foundationkit/core';

sendOffer({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like ethers.js.

```js
import { sendOffer } from '@foundationkit/core';

sendOffer({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are making an offer on.

```js
import { sendOffer } from '@foundationkit/core';

sendOffer({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are making an offer on.

```js
import { sendOffer } from '@foundationkit/core';

sendOffer({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### amount (required)

A string value representing the offer amount, it is read as eth.

```js
import { sendOffer } from '@foundationkit/core';

sendOffer({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### referrer

A valid Ethereum address that will receive a referral fee of 1% of the sale price, if this NFT is bought via this hook. [Learn more about referrals](https://help.foundation.app/hc/en-us/articles/6155086291739)

```js
import { sendOffer } from '@foundationkit/core';

sendOffer({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
  referrer: '0x165CD37b4C644C2921454429E7F9358d18A45e14',
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { sendOffer } from '@foundationkit/core';

sendOffer({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `getLastSoldPrice`

Function for fetching the last sold price of an NFT within Foundation's Market.

```js
import { getLastSoldPrice } from '@foundationkit/core';
```

#### Usage

An Provider must be passed in from either a library like wagmi or ethers.js.

```js
import { getLastSoldPrice } from '@foundationkit/core';

getLastSoldPrice({
  provider,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
{
  value: BigNumber;
  formatted: string;
}
```

#### Configuration

##### provider (required)

An Ethereum Provider must be provided from a library like ethers.js.

```js
import { getLastSoldPrice } from '@foundationkit/core';

getLastSoldPrice({
  provider,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are fetching the last sold price for.

```js
import { getLastSoldPrice } from '@foundationkit/core';

getLastSoldPrice({
  // provider,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are fetching the last sold price for.

```js
import { getLastSoldPrice } from '@foundationkit/core';

getLastSoldPrice({
  // provider,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

---

### `getApproval`

Function for checking if an address has approved Foundation's market contract.

```js
import { getApproval } from '@foundationkit/core';
```

#### Usage

A Provider must be passed in from either a library like ethers.js.

```js
import { getApproval } from '@foundationkit/core';

getApproval({
  provider,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  ownerAddress: '0x2ae5f36c77a736f76d61f3eec06f12caf2963fd6',
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
isApproved: boolean;
```

#### Configuration

##### provider (required)

An Ethereum Provider must be provided from a library like ethers.js.

```js
import { getApproval } from '@foundationkit/core';

getApproval({
  provider,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // ownerAddress: '0x2ae5f36c77a736f76d61f3eec06f12caf2963fd6',
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are checking is approved.

```js
import { getApproval } from '@foundationkit/core';

getApproval({
  // provider,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // ownerAddress: '0x2ae5f36c77a736f76d61f3eec06f12caf2963fd6',
}).then((data) => {
  console.log(data);
});
```

##### ownerAddress (required)

A valid ethereum address for the user who has provided approval.

```js
import { getApproval } from '@foundationkit/core';

getApproval({
  // provider,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  ownerAddress: '0x2ae5f36c77a736f76d61f3eec06f12caf2963fd6',
}).then((data) => {
  console.log(data);
});
```

---

### `setApproval`

Function for setting approval for the Foundation Market contract to perform actions on an NFT you own.

```js
import { setApproval } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
import { setApproval } from '@foundationkit/core';

setApproval({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like ethers.js.

```js
import { setApproval } from '@foundationkit/core';

setApproval({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you would like to approve.

```js
import { setApproval } from '@foundationkit/core';

setApproval({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { setApproval } from '@foundationkit/core';

setApproval({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `setReserveAuction`

Function for creating a reserve auction & setting a reserve price on Foundation's market contract.

```js
import { setReserveAuction } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
import { setReserveAuction } from '@foundationkit/core';

setReserveAuction({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like ethers.js.

```js
import { setReserveAuction } from '@foundationkit/core';

setReserveAuction({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are listing in the auction.

```js
import { setReserveAuction } from '@foundationkit/core';

setReserveAuction({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are listing in the auction.

```js
import { setReserveAuction } from '@foundationkit/core';

setReserveAuction({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### amount (required)

A string value representing the reserve price for the NFT being listed.

```js
import { setReserveAuction } from '@foundationkit/core';

setReserveAuction({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { setReserveAuction } from '@foundationkit/core';

setReserveAuction({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `setBuyNow`

Function for listing an NFT with a Buy Now price.

```js
import { setBuyNow } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
import { setBuyNow } from '@foundationkit/core';

setBuyNow({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like ethers.js.

```js
import { setBuyNow } from '@foundationkit/core';

setBuyNow({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are listing with a Buy Now price.

```js
import { setBuyNow } from '@foundationkit/core';

setBuyNow({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are listing with a Buy Now price.

```js
import { setBuyNow } from '@foundationkit/core';

setBuyNow({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  // amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### amount (required)

A string value representing the Buy Now price for the NFT being listed.

```js
import { setBuyNow } from '@foundationkit/core';

setBuyNow({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  amount: '1.1',
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { setBuyNow } from '@foundationkit/core';

setBuyNow({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '1.1',
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `cancelBuyNow`

Function to cancel a Buy Now listing.

```js
import { cancelBuyNow } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
import { cancelBuyNow } from '@foundationkit/core';

cancelBuyNow({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like ethers.js.

```js
import { cancelBuyNow } from '@foundationkit/core';

cancelBuyNow({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are cancelling the listing for.

```js
import { cancelBuyNow } from '@foundationkit/core';

cancelBuyNow({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are cancelling the listing for.

```js
import { cancelBuyNow } from '@foundationkit/core';

cancelBuyNow({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { cancelBuyNow } from '@foundationkit/core';

cancelBuyNow({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `cancelReserveAuction`

Function to cancel a Reserve auction liting. This will only work if the auction has not started yet.

```js
import { cancelReserveAuction } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
import { cancelReserveAuction } from '@foundationkit/core';

cancelReserveAuction({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like ethers.js.

```js
import { cancelReserveAuction } from '@foundationkit/core';

cancelReserveAuction({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are cancelling the listing for.

```js
import { cancelReserveAuction } from '@foundationkit/core';

cancelReserveAuction({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are cancelling the listing for.

```js
import { cancelReserveAuction } from '@foundationkit/core';

cancelReserveAuction({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { cancelReserveAuction } from '@foundationkit/core';

cancelReserveAuction({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `acceptOffer`

Function to accept an active offer on an NFT you own.

```js
import { acceptOffer } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
import { acceptOffer } from '@foundationkit/core';

acceptOffer({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  amount: '0.1',
  offererAddress: '0x7E6d171d288ecED6eB2D070D8e46Aa905b0f94aE',
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like ethers.js.

```js
import { acceptOffer } from '@foundationkit/core';

acceptOffer({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '0.1',
  // offererAddress: '0x7E6d171d288ecED6eB2D070D8e46Aa905b0f94aE',
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are accepting an offer for.

```js
import { acceptOffer } from '@foundationkit/core';

acceptOffer({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '0.1',
  // offererAddress: '0x7E6d171d288ecED6eB2D070D8e46Aa905b0f94aE',
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are accepting an offer for.

```js
import { acceptOffer } from '@foundationkit/core';

acceptOffer({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  // amount: '0.1',
  // offererAddress: '0x7E6d171d288ecED6eB2D070D8e46Aa905b0f94aE',
}).then((data) => {
  console.log(data);
});
```

##### amount (required)

The amount the offer is for that you wish to accept. You can get this value from the `getMarketInfo` function.

```js
import { acceptOffer } from '@foundationkit/core';

acceptOffer({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  amount: '0.1',
  // offererAddress: '0x7E6d171d288ecED6eB2D070D8e46Aa905b0f94aE',
}).then((data) => {
  console.log(data);
});
```

##### offererAddress (required)

The Ethereum address of the person making the offer. You can get this value from the `getMarketInfo` function.

```js
import { acceptOffer } from '@foundationkit/core';

acceptOffer({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '0.1',
  offererAddress: '0x7E6d171d288ecED6eB2D070D8e46Aa905b0f94aE',
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { acceptOffer } from '@foundationkit/core';

function App() {
  const acceptOffer = acceptOffer({
    // signer,
    // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
    // tokenId: 8,
    // amount: '0.1',
    // offererAddress: '0x7E6d171d288ecED6eB2D070D8e46Aa905b0f94aE',
    // Will send 15% more gas, based on the estimate gas calculation
    gasMargin: 15,
  });
}

acceptOffer({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
  // amount: '0.1',
  // offererAddress: '0x7E6d171d288ecED6eB2D070D8e46Aa905b0f94aE',
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `finalizeReserveAuction`

Function to finalize an reserve auction, it initiates the transfer of the NFT to the new owner and the payment amount to the seller and can be called by anyone.

```js
import { finalizeReserveAuction } from '@foundationkit/core';
```

#### Usage

An Signer must be passed in from either a library like ethers.js.

```js
import { finalizeReserveAuction } from '@foundationkit/core';

finalizeReserveAuction({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
txResponse: Promise<TransactionResponse>
```

#### Configuration

##### signer (required)

An Ethereum Signer must be provided from a library like wagmi or ethers.js.

```js
import { finalizeReserveAuction } from '@foundationkit/core';

finalizeReserveAuction({
  signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### contractAddress (required)

A valid ethereum address for the smart contract of the NFT you are finalizing the auction for.

```js
import { finalizeReserveAuction } from '@foundationkit/core';

finalizeReserveAuction({
  // signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  // tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### tokenId (required)

A valid token ID of the NFT you are finalizing the auction for.

```js
import { finalizeReserveAuction } from '@foundationkit/core';

finalizeReserveAuction({
  // signer,
  // contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
}).then((data) => {
  console.log(data);
});
```

##### gasMargin

By default we add a 10% gas margin to ensure tx's are processed (a good default to mitigate edge cases and ensuring there is a gas buffer), you can override this by passing a number that represents a % of the original gas estimation.

```js
import { finalizeReserveAuction } from '@foundationkit/core';

finalizeReserveAuction({
  signer,
  contractAddress: '0x47609b1a83B2Fc92C8AD632aE093AC61d9A85295',
  tokenId: 8,
  // Will send 15% more gas, based on the estimate gas calculation
  gasMargin: 15,
}).then((data) => {
  console.log(data);
});
```

---

### `getBalances`

Function for accessing an accounts ETH and FETH balances, these can be locked and available depending if offers have been placed and expired. [Learn more about Marketplace balances](https://help.foundation.app/hc/en-us/articles/6601042998299-Everything-You-Need-to-Know-About-Marketplace-Balance)

```js
import { getBalances } from '@foundationkit/core';
```

#### Usage

A Provider must be passed in from either a library like ethers.js.

```js
import { getBalances } from '@foundationkit/core';

function App() {
  const { data, isLoading } = useBalances({
    provider,
    accountAddress: '0x61bC292750B648Fa9502f8FEBeBd806c3b484ACe',
  });
}

getBalances({
  provider,
  accountAddress: '0x61bC292750B648Fa9502f8FEBeBd806c3b484ACe',
}).then((data) => {
  console.log(data);
});
```

#### Return Value

```ts
{
  ensName: string;
  ethBalance: {
    value: BigNumber;
    formatted: string;
  }
  availableFethBalance: {
    value: BigNumber;
    formatted: string;
  }
  lockedFethBalance: {
    value: BigNumber;
    formatted: string;
  }
}
```

#### Configuration

##### provider (required)

An Ethereum Provider must be provided from a library like ethers.js.

```js
import { getBalances } from '@foundationkit/core';

getBalances({
  provider,
  // accountAddress: '0x61bC292750B648Fa9502f8FEBeBd806c3b484ACe',
}).then((data) => {
  console.log(data);
});
```

##### accountAddress (required)

A valid ethereum address for the account you are looking up balances for.

```js
import { getBalances } from '@foundationkit/core';

getBalances({
  // provider,
  accountAddress: '0x61bC292750B648Fa9502f8FEBeBd806c3b484ACe',
}).then((data) => {
  console.log(data);
});
```

### TODO

- Withdraw feth balance
